@@ -1,6 +1,7 @@
+
+
 name = "lgt_jobs"
 
-from .jobs.user_balance_update import UpdateUserBalanceJob, UpdateUserBalanceJobData
 from .jobs.send_slack_message import SendSlackMessageJob, SendSlackMessageJobData
 from .jobs.analytics import (TrackAnalyticsJob, TrackAnalyticsJobData)
 from .jobs.connect_sources import (ConnectSourceJobData, ConnectSourceJob)
@@ -13,6 +14,9 @@ from .smtp import (SendMailJob, SendMailJobData)
 from .runner import (BackgroundJobRunner)
 from .simple_job import (SimpleTestJob, SimpleTestJobData)
 from .jobs.load_slack_people import (LoadSlackPeopleJob, LoadSlackPeopleJobData)
+from .jobs.load_slack_users import LoadSlackUsersJob, LoadSlackUsersJobData
+from .jobs.bots_killer import BotsKillerJob, BotsKillerData
+from .jobs.send_slack_invites import SendSlackInvitesJob, SendSlackInvitesJobData
 
 jobs_map = {
     "SimpleTestJob": SimpleTestJob,
@@ -22,10 +26,12 @@ jobs_map = {
     "LoadChatHistoryJob": LoadChatHistoryJob,
     "UpdateExternalUserProfileJob": UpdateExternalUserProfileJob,
     "SendSlackMessageJob": SendSlackMessageJob,
-    "UpdateUserBalanceJob": UpdateUserBalanceJob,
     "SendMassMessageSlackChannelJob": SendMassMessageSlackChannelJob,
     "ConnectSourceJob": ConnectSourceJob,
-    "LoadSlackPeopleJob": LoadSlackPeopleJob
+    "LoadSlackPeopleJob": LoadSlackPeopleJob,
+    "BotsKillerJob": BotsKillerJob,
+    "LoadSlackUsersJob": LoadSlackUsersJob,
+    "SendSlackInvitesJob": SendSlackInvitesJob
 }
 __all__ = [
     # Jobs
@@ -37,10 +43,12 @@ __all__ = [
     UpdateExternalUserProfileJob,
     TrackAnalyticsJob,
     SendSlackMessageJob,
-    UpdateUserBalanceJob,
     SendMassMessageSlackChannelJob,
     ConnectSourceJob,
     LoadSlackPeopleJob,
+    LoadSlackUsersJob,
+    BotsKillerJob,
+    SendSlackInvitesJob,
 
     # module classes
     BackgroundJobRunner,
@@ -54,10 +62,12 @@ __all__ = [
     UpdateExternalUserProfileJobData,
     TrackAnalyticsJobData,
     SendSlackMessageJobData,
-    UpdateUserBalanceJobData,
     SendMassMessageSlackChannelJobData,
     ConnectSourceJobData,
     LoadSlackPeopleJobData,
+    LoadSlackUsersJobData,
+    BotsKillerData,
+    SendSlackInvitesJobData,
     # mapping
     jobs_map
 ]
