@@ -2,7 +2,7 @@ import os
 
 project_id = os.environ.get('PROJECT_ID')
 background_jobs_topic = os.environ.get('BACKGROUND_JOBS_TOPIC')
-background_jobs_subscriber = os.environ.get('BACKGROUND_JOBS_SUBSCRIBER')
+background_jobs_subscriber = os.environ.get('BACKGROUND_JOBS_SUBSCRIBER', 'subscriber')
 mongo_connection_string = os.environ.get('MONGO_CONNECTION_STRING')
 smtp_host = os.environ.get('SMTP_HOST')
 smtp_login = os.environ.get('SMTP_LOGIN')
@@ -14,3 +14,6 @@ service_account_password = os.environ.get('SERVICE_ACCOUNT_PASSWORD')
 v2_server_host = os.environ.get('V2_SERVER_HOST')
 v3_server_host = os.environ.get('V3_SERVER_HOST')
 v1_server_host = os.environ.get('V1_SERVER_HOST')
+max_messages = int(os.environ.get('MAX_MESSAGES', 10))
+pool_size = int(os.environ.get('POOL_SIZE', 10))
+v3_background_job_topic = os.environ.get('V3_BACKGROUND_JOBS_TOPIC')
