@@ -1,20 +1,22 @@
+from abc import ABC
 from typing import Optional
-from loguru import logger as log
-from lgt.common.python.slack_client.web_client import SlackWebClient
-from ..basejobs import BaseBackgroundJobData, BaseBackgroundJob
+import logging as log
+from lgt_jobs.lgt_common.slack_client.web_client import SlackWebClient
+from pydantic import BaseModel
+from lgt_jobs.basejobs import BaseBackgroundJobData, BaseBackgroundJob
 
 """
 Send Slack Code
 """
 
 
-class SendSlackEmailJobData(BaseBackgroundJobData):
+class SendSlackEmailJobData(BaseBackgroundJobData, BaseModel):
     email: str
     user_agent: str
     locale: Optional[str]
 
 
-class SendSlackEmailJob(BaseBackgroundJob):
+class SendSlackEmailJob(BaseBackgroundJob, ABC):
     @property
     def job_data_type(self) -> type:
         return SendSlackEmailJobData
@@ -23,5 +25,5 @@ class SendSlackEmailJob(BaseBackgroundJob):
         client = SlackWebClient('')
         code_sent = client.confirm_email(data.email, data.user_agent, data.locale)
         if not code_sent:
-            log.warning(f'Unable to confirm code due to error: {code_sent.content}')
+            log.warning(f'Unable to confirm code due to error: {code_sent}')
             return
