@@ -1,11 +1,9 @@
-from datetime import datetime, UTC
 from abc import ABC
 from typing import Optional
 import logging as log
-from lgt_jobs.lgt_common.slack_client.web_client import SlackWebClient, SlackMessageConvertService
-from lgt_jobs.lgt_data.model import ChatMessage
-from lgt_jobs.lgt_data.mongo_repository import DedicatedBotRepository, UserContactsRepository, UserMongoRepository, \
-    ChatRepository
+from lgt_jobs.lgt_common.slack_client.web_client import SlackWebClient
+from lgt_jobs.lgt_data.models.chat.message import ChatMessage
+from lgt_jobs.lgt_data.mongo_repository import DedicatedBotRepository, ChatRepository
 from pydantic import BaseModel
 from lgt_jobs.basejobs import BaseBackgroundJobData, BaseBackgroundJob
 
@@ -31,14 +29,6 @@ class SendSlackMessageJob(BaseBackgroundJob, ABC):
         if not bot:
             return
 
-        user = UserMongoRepository().get(bot.user_id)
-        user_contacts_repository = UserContactsRepository()
-        uc = user_contacts_repository.find_one(bot.user_id, sender_id=data.sender_id,
-                                               source_id=bot.source.source_id)
-        uc.scheduled_messages = [message.to_dic() for message in uc.scheduled_messages
-                                 if message.post_at.replace(tzinfo=UTC) > datetime.now(UTC)]
-        user_contacts_repository.update(bot.user_id, uc.sender_id, bot.source.source_id,
-                                        scheduled_messages=uc.scheduled_messages)
         slack_client = SlackWebClient(bot.token, bot.cookies)
         im = slack_client.im_open(data.sender_id)
         if not im['ok']:
@@ -54,7 +44,6 @@ class SendSlackMessageJob(BaseBackgroundJob, ABC):
         message = resp.get('message') if 'message' in resp \
             else slack_client.conversation_replies(channel_id, resp['file_msg_ts'])['messages'][0]
 
-        message_model: ChatMessage = SlackMessageConvertService.from_slack_response(bot.user_name, message,
-                                                                                    data.sender_id, bot.id, user.id)
+        message_model: ChatMessage = ChatMessage().from_slack_response(bot, message, data.sender_id)
         message_model.viewed = True
         ChatRepository().upsert_messages([message_model.to_dic()])
