@@ -8,7 +8,7 @@ from lgt_jobs.lgt_data.mongo_repository import to_object_id
 from pymongo import MongoClient
 
 client = MongoClient(os.environ.get('MONGO_CONNECTION_STRING', 'mongodb://127.0.0.1:27017/'))
-db = client.lgt_admin
+db = client.get_database('lgt_admin')
 
 
 def _build_date_aggregated_analytics_pipeline(source_id=None, email=None, started_at: datetime = None,
@@ -81,6 +81,7 @@ def _prepare_date_analytics_doc(doc, ordered_result_dict: Dict[str, int]):
         ordered_result_dict[str_date] = item["count"]
     return ordered_result_dict
 
+
 def get_channel_aggregated_analytics(from_date: datetime = None, to_date: datetime = None,
                                      bot_id: Optional[str | ObjectId] = None):
     pipeline = [
@@ -367,12 +368,11 @@ def get_date_aggregated_analytics(source_id=None, started_at: datetime = None,
     pipeline: list = _build_date_aggregated_analytics_pipeline(source_id=source_id, started_at=started_at,
                                                                ended_at=ended_at, bots_ids=bots_ids)
 
-    received_messages = list(db[f'received_messages'].aggregate(pipeline))
-
     if configs is not None:
-        pipeline.insert(0, {"$match": {"attributes": {'$in': configs}}})
+        pipeline.insert(0, {"$match": {"configs.id": {'$in': configs}}})
 
     filtered_messages = list(db[f'filtered_messages'].aggregate(pipeline))
+    received_messages = list(db[f'received_messages'].aggregate(pipeline))
 
     received_messages_dic = _create_result_dic(started_at, ended_at)
     filtered_messages_dic = _create_result_dic(started_at, ended_at)
@@ -394,7 +394,7 @@ def get_leads_aggregated_analytics(from_date: datetime = None, to_date: datetime
         }
     ]
     if user_id:
-        pipeline.insert(0, {"$match": {"user_ids": {"$in": [str(user_id)]}}})
+        pipeline.insert(0, {"$match": {"user_ids": {"$in": [to_object_id(user_id)]}}})
 
     if from_date:
         beginning_of_the_day = datetime(from_date.year, from_date.month, from_date.day)
@@ -540,12 +540,12 @@ def get_bots_aggregated_analytics(from_date: datetime = None,
     if bot_ids is not None:
         pipeline.insert(0, {"$match": {"extra_ids": {"$in": bot_ids}}})
 
-    received_messages = list(db[f'received_messages'].aggregate(pipeline))
+    received_messages = list(db.get_collection('received_messages').aggregate(pipeline))
 
     if configs is not None:
         pipeline.insert(0, {"$match": {"attributes": {"$in": configs}}})
 
-    filtered_messages = list(db[f'filtered_messages'].aggregate(pipeline))
+    filtered_messages = list(db.get_collection('filtered_messages').aggregate(pipeline))
     received_messages_dic = OrderedDict()
     filtered_messages_dic = OrderedDict()
 
