@@ -1,19 +1,35 @@
 import os
-import re
 from typing import List, Optional
 import pymongo
 from dateutil import tz
 from pymongo import MongoClient, UpdateOne
 from bson.objectid import ObjectId
 from lgt_jobs.lgt_data.enums import SourceType
-from lgt_jobs.lgt_data.model import (LeadModel, BaseModel, UserModel, UserResetPasswordModel, BoardModel, BoardedStatus,
-                                     DedicatedBotModel, SlackMemberInformation, UserTemplateModel,
-                                     ExtendedUserLeadModel, UserLeadModel, ExtendedLeadModel, UserContact, ChatMessage,
-                                     GroupedMessagesModel, UserVerificationModel, UsersPage, Subscription,
-                                     ScheduledMessage)
 from datetime import datetime, UTC, timedelta
 from collections import OrderedDict
 
+from lgt_jobs.lgt_data.models.base import BaseModel
+from lgt_jobs.lgt_data.models.boards.board import BoardModel
+from lgt_jobs.lgt_data.models.boards.status import BoardedStatus
+from lgt_jobs.lgt_data.models.bots.dedicated_bot import DedicatedBotModel
+from lgt_jobs.lgt_data.models.chat.grouped_messages import GroupedMessagesModel
+from lgt_jobs.lgt_data.models.chat.message import ChatMessage
+from lgt_jobs.lgt_data.models.chat.scheduled_message import ScheduledMessage
+from lgt_jobs.lgt_data.models.chat.request import MessageRequest
+from lgt_jobs.lgt_data.models.contacts.contact import UserContact
+from lgt_jobs.lgt_data.models.leads.extended_lead import ExtendedLeadModel
+from lgt_jobs.lgt_data.models.leads.lead import LeadModel
+from lgt_jobs.lgt_data.models.people.people import SlackMemberInformation
+from lgt_jobs.lgt_data.models.templates.template import UserTemplateModel
+from lgt_jobs.lgt_data.models.user.reset_password import UserResetPasswordModel
+from lgt_jobs.lgt_data.models.user.subscription import Subscription
+from lgt_jobs.lgt_data.models.user.user import UserModel
+from lgt_jobs.lgt_data.models.user.user_follow_ups import UserFollowUps
+from lgt_jobs.lgt_data.models.user.user_page import UsersPage
+from lgt_jobs.lgt_data.models.user.verification import UserVerificationModel
+from lgt_jobs.lgt_data.models.user_leads.extended_user_lead import ExtendedUserLeadModel
+from lgt_jobs.lgt_data.models.user_leads.user_lead import UserLeadModel
+
 client = MongoClient(os.environ.get('MONGO_CONNECTION_STRING', 'mongodb://127.0.0.1:27017/'))
 
 
@@ -35,13 +51,13 @@ class BaseMongoRepository:
         return client[self.database_name][collection_name]
 
     def insert_many(self, items):
-        insert_items = map(lambda x: x.to_dic(), items)
+        insert_items = [item.to_dic() for item in items]
         self.collection().insert_many(insert_items)
 
-    def insert(self, item: BaseModel):
+    def insert(self, item):
         return self.collection().insert_one(item.to_dic())
 
-    def add(self, item: BaseModel):
+    def add(self, item):
         return self.insert(item)
 
     def delete(self, id):
@@ -53,6 +69,23 @@ class UserMongoRepository(BaseMongoRepository):
     collection_name = 'users'
     model = UserModel
 
+    def get_inactive_users(self):
+        pipeline = [
+            {'$lookup': {'from': 'user_track_action', 'as': 'last_action', 'let': {'id': '$_id' }, 'pipeline':
+                [
+                    {'$match': {'$expr': {'$eq': ['$user_id', '$$id']}}},
+                    {'$sort': {'created_at': -1}},
+                    {'$project': {'created_at': 1}},
+                    {'$limit': 1}
+                ]}},
+            {'$addFields': {'last_action_date': {'$first': '$last_action.created_at'}}},
+            {'$lookup': {'as': 'subscription', 'from': 'subscriptions', 'foreignField': '_id', 'localField': 'subscription_id'}},
+            {'$addFields': {'period': {'$first': '$subscription.disable_bots_period'}}},
+            {'$match': {'$expr': {'$lte': ['$last_action_date', {'$dateSubtract': {'startDate': '$$NOW', 'unit': 'day', 'amount': '$period'}}]}}},
+            {'$project': {'_id': 1}}]
+
+        return {doc['_id']: None for doc in self.collection().aggregate(pipeline)}
+
     def get(self, _id):
         return UserModel.from_dic(self.collection().find_one({'_id': to_object_id(_id)}))
 
@@ -65,12 +98,19 @@ class UserMongoRepository(BaseMongoRepository):
         update_dict = {k: v for k, v in kwargs.items() if v is not None}
         self.collection().update_one({'_id': to_object_id(_id)}, {'$set': update_dict})
 
-    def get_users(self, users_ids=None, include_inactive=False, **kwargs):
+    def get_users(self, users_ids=None, include_inactive=False, name=None, **kwargs):
         pipeline = {}
 
         subscription_expired = kwargs.get('subscription_expired')
+        connected_slack_email = kwargs.get('connected_slack_email')
         soon_subscription_expiration = kwargs.get('soon_subscription_expiration')
+        has_new_message = kwargs.get('has_new_message')
+        has_new_message_request = kwargs.get('has_new_message_request')
+        has_deactivated_sources = kwargs.get('has_deactivated_sources')
+        has_new_replies = kwargs.get('has_new_replies')
+        has_new_reactions = kwargs.get('has_new_reactions')
         min_days = kwargs.get('min_days_soon_subscription_expiration', 3)
+        emails = kwargs.get('emails')
 
         if subscription_expired:
             pipeline['subscription_expired_at'] = {'$lte': datetime.now(UTC)}
@@ -80,27 +120,59 @@ class UserMongoRepository(BaseMongoRepository):
             pipeline['subscription_expired_at'] = {'$lte': datetime.now(UTC) + timedelta(min_days)}
             pipeline['subscription_expiration_warning_notified'] = False
 
+        if has_new_message:
+            pipeline['notification_settings.incoming_messages.enabled'] = True
+            pipeline['notification_settings.incoming_messages.need_to_notify'] = True
+
+        if has_new_message_request:
+            pipeline['notification_settings.inbox.enabled'] = True
+            pipeline['notification_settings.inbox.need_to_notify'] = True
+
+        if has_deactivated_sources:
+            pipeline['notification_settings.source_deactivation.enabled'] = True
+            pipeline['notification_settings.source_deactivation.need_to_notify'] = True
+
+        if has_new_replies:
+            pipeline['notification_settings.bulk_replies.enabled'] = True
+            pipeline['notification_settings.bulk_replies.need_to_notify'] = True
+
+        if has_new_reactions:
+            pipeline['notification_settings.bulk_reactions.enabled'] = True
+            pipeline['notification_settings.bulk_reactions.need_to_notify'] = True
+
+        if connected_slack_email:
+            pipeline['slack_users.email'] = connected_slack_email
+
         if users_ids is not None:
             pipeline['_id'] = {'$in': [to_object_id(_id) for _id in users_ids]}
 
+        if emails is not None:
+            pipeline['email'] = {'$in': emails}
+
+        if name is not None:
+            pipeline['user_name'] = {"$regex": name, "$options": 'i'}
+
         if not include_inactive:
             pipeline['inactive'] = False
 
         return [UserModel.from_dic(doc) for doc in self.collection().find(pipeline)]
 
     def get_users_page(self, skip: int = 0, limit: int = 50, **kwargs):
-        pipeline = []
+        pipeline: list = []
         match_pipeline = {}
         include_inactive = kwargs.get('include_inactive', False)
         email = kwargs.get('email')
         search = kwargs.get('search')
+        name = kwargs.get('name')
         sort_field = kwargs.get('sort_field', 'email')
         sort_direction = kwargs.get('sort_direction', 'ASCENDING')
-        sort_direction: int = pymongo.ASCENDING if sort_direction == 'ASCENDING' else pymongo.DESCENDING
+        sort_direction = pymongo.ASCENDING if sort_direction == 'ASCENDING' else pymongo.DESCENDING
         if not include_inactive:
             match_pipeline['inactive'] = False
         if email:
             match_pipeline['email'] = email
+        if name:
+            match_pipeline['user_name'] = {'$regex': name, '$options': 'i'}
         if search:
             match_pipeline['email'] = {'$regex': search, '$options': 'i'}
         pipeline.append({'$match': match_pipeline})
@@ -166,6 +238,124 @@ class UserLeadMongoRepository(BaseMongoRepository):
     collection_name = 'user_leads'
     model = ExtendedUserLeadModel
 
+    def get_leads_with_follow_ups(self):
+        now = datetime.now(UTC)
+        this_day = datetime(now.year, now.month, now.day, 21, 00, 00, tzinfo=UTC)
+        after_week = this_day + timedelta(7)
+        previous_day = this_day - timedelta(1)
+        pipeline = [
+            {'$match': {'archived': False, 'followup_date': {'$ne': None}}},
+            {
+                '$lookup': {
+                    'from': 'users',
+                    'localField': 'user_id',
+                    'foreignField': '_id',
+                    'as': 'user'
+                }
+            },
+            {
+                '$lookup': {
+                    'from': 'slack_contact',
+                    'localField': 'message.sender_id',
+                    'foreignField': 'sender_id',
+                    'as': 'contact'
+                }
+            },
+            {'$addFields': {'contact': {'$first': '$contact'}, 'user': {'$first': '$user'}}},
+            {
+                '$project': {
+                    'user_id': 1,
+                    'user_email': '$user.email',
+                    'notification_settings': '$user.notification_settings',
+                    'subscription_id': "$user.subscription_id",
+                    'followup_to': {
+                        '$switch': {
+                            'branches': [
+                                {
+                                    'case': {'$eq': ['$user.notification_settings.follow_ups.type', 'once_a_day']},
+                                    'then': this_day
+                                },
+                                {
+                                    'case': {'$eq': ['$user.notification_settings.follow_ups.type', 'once_a_week']},
+                                    'then': after_week
+                                },
+                                {
+                                    'case': {'$eq': ['$user.notification_settings.follow_ups.type',
+                                                     'unread_for_few_minutes']},
+                                    'then': {
+                                        '$dateAdd': {
+                                            'startDate': now,
+                                            'unit': 'minute',
+                                            'amount': '$user.notification_settings.follow_ups.minute'
+                                        }
+                                    }
+                                }
+                            ],
+                            'default': this_day
+                        }
+                    },
+                    'followup_date': 1,
+                    'contact': 1,
+                    'message.sender_id': 1,
+                    'message.source': 1
+                }
+            },
+            {'$group': {'_id': '$user_id', 'leads': {'$push': '$$ROOT'}}},
+            {
+                '$addFields': {
+                    'actual_follow_ups': {
+                        '$filter': {
+                            'input': '$leads',
+                            'as': 'lead',
+                            'cond': {
+                                '$and': [
+                                    {
+                                        '$gte': [
+                                            '$$lead.followup_date',
+                                            {'$cond': [
+                                                {
+                                                    '$eq': ['$$lead.notification_settings.follow_ups.type',
+                                                            'unread_for_few_minutes']
+                                                 },
+                                                now,
+                                                previous_day]}]},
+                                    {
+                                        '$lte': ['$$lead.followup_date', '$$lead.followup_to']}]}}
+                    },
+                    'overdue_follow_ups': {
+                        '$filter': {
+                            'input': '$leads',
+                            'as': 'lead',
+                            'cond': {
+                                '$lt': [
+                                    '$$lead.followup_date',
+                                    {'$cond': [
+                                        {
+                                            '$eq': ['$notification_settings.follow_ups.type', 'unread_for_few_minutes']
+                                        },
+                                        now,
+                                        previous_day]}]}}}}
+            },
+            {
+                '$addFields': {
+                    'email': {'$first': '$leads.user_email'},
+                    'notification_settings': {'$first': '$leads.notification_settings'},
+                    'subscription_id': {'$first': '$leads.subscription_id'}
+                }
+            },
+            {'$match': {'actual_follow_ups': {'$ne': []}}},
+            {'$unset': ['leads']}
+        ]
+        return [UserFollowUps.from_dic(doc) for doc in list(self.collection().aggregate(pipeline))]
+
+    def update_source(self, source_id: str, source_data: dict):
+        self.collection().update_many({'message.source.source_id': source_id},
+                                      {'$set': {'message.source': source_data}})
+
+    def update_many_by_sender_id(self, sender_id: str, **kwargs):
+        update_dict = {k: v for k, v in kwargs.items() if v is not None}
+        self.collection().update_many({'message.sender_id': sender_id}, {'$set': update_dict}, upsert=False)
+
     def get_many(self, ids: list, user_id):
         docs = self.collection().find({"id": {'$in': ids}, 'user_id': to_object_id(user_id)})
         leads = [ExtendedUserLeadModel.from_dic(lead) for lead in docs]
@@ -204,23 +394,22 @@ class UserLeadMongoRepository(BaseMongoRepository):
         archived = kwargs.get('archived')
         from_date = kwargs.get('from_date')
         to_date = kwargs.get('to_date')
-        has_followup = kwargs.get('has_followup', None)
-        followup_to = kwargs.get('followup_to_date', None)
-        followup_from = kwargs.get('followup_from_date', None)
-        created_to = kwargs.get('created_to_date', None)
-        created_from = kwargs.get('created_from_date', None)
-        sender_ids = kwargs.get('sender_ids', None)
-        text = kwargs.get('text', None)
-        stop_words = kwargs.get('stop_words', None)
-        tags = kwargs.get('tags', None)
-        configs = kwargs.get('config', None)
-        bots_names = kwargs.get('bots_names', None)
-        locations = kwargs.get('locations', None)
-        dedicated_bots_ids = kwargs.get('dedicated_bots_ids', None)
-        with_chat = kwargs.get('with_chat', None)
-        leads_ids = kwargs.get('leads_ids', None)
-        exclude_leads = kwargs.get('exclude_leads', None)
-        exclude_senders = kwargs.get('exclude_senders', None)
+        has_followup = kwargs.get('has_followup')
+        followup_to = kwargs.get('followup_to_date')
+        followup_from = kwargs.get('followup_from_date')
+        created_to = kwargs.get('created_to_date')
+        created_from = kwargs.get('created_from_date')
+        sender_ids = kwargs.get('sender_ids')
+        text = kwargs.get('text')
+        stop_words = kwargs.get('stop_words')
+        tags = kwargs.get('tags')
+        configs = kwargs.get('config')
+        bots_names = kwargs.get('bots_names')
+        locations = kwargs.get('locations')
+        with_chat = kwargs.get('with_chat')
+        leads_ids = kwargs.get('leads_ids')
+        exclude_leads = kwargs.get('exclude_leads')
+        exclude_senders = kwargs.get('exclude_senders')
 
         pipeline['message.profile.display_name'] = {
             "$ne": "Slackbot"
@@ -297,8 +486,6 @@ class UserLeadMongoRepository(BaseMongoRepository):
         if bots_names is not None:
             pipeline['message.name'] = {'$in': bots_names}
 
-        if dedicated_bots_ids is not None:
-            pipeline["message.dedicated_slack_options.bot_id"] = {"$in": dedicated_bots_ids}
         return pipeline
 
     def get_daily_analytics_by_workspace(self, user_configs: list,
@@ -457,6 +644,10 @@ class LeadMongoRepository(BaseMongoRepository):
     collection_name = 'general_leads'
     model = LeadModel
 
+    def update_source(self, source_id: str, source_data: dict):
+        self.collection().update_many({'message.source.source_id': source_id},
+                                      {'$set': {'message.source': source_data}})
+
     def delete(self, _id):
         res = self.collection().delete_one({'id': _id})
         return res
@@ -511,103 +702,6 @@ class LeadMongoRepository(BaseMongoRepository):
         update_dict = {k: v for k, v in kwargs.items() if v is not None}
         self.collection().update_one({'id': _id}, {'$set': update_dict}, upsert=False)
 
-    def get_list(self, skip, limit, **kwargs):
-        pipeline = self.__create_leads_filter(**kwargs)
-
-        sort_field = kwargs.get('sort_field', 'created_at')
-        sort_direction = kwargs.get('sort_direction', 'ASCENDING')
-        sort_direction = pymongo.ASCENDING if sort_direction == 'ASCENDING' else pymongo.DESCENDING
-
-        leads = self.collection().find(pipeline).sort([(sort_field, sort_direction)]).skip(skip).limit(limit)
-        return [LeadModel.from_dic(lead) for lead in leads]
-
-    def __create_leads_filter(self, **kwargs):
-        pipeline: dict = {"hidden": False}
-
-        from_date: datetime = kwargs.get('from_date')
-        to_date: datetime = kwargs.get('to_date')
-
-        country = kwargs.get('country', None)
-        user_id = kwargs.get('user_id', None)
-        tags = kwargs.get('tags', None)
-        text = kwargs.get('text', None)
-        stop_words = kwargs.get('stop_words', None)
-        exclude_leads = kwargs.get('exclude_leads', None)
-        exclude_senders = kwargs.get('exclude_senders', None)
-        excluded_channels = kwargs.get('excluded_channels', None)
-        sender_ids = kwargs.get('sender_ids', None)
-        configs = kwargs.get('config', None)
-        bots_names = kwargs.get('bots_names', None)
-        locations = kwargs.get('locations', None)
-        publication_text = kwargs.get('publication_text')
-
-        pipeline['message.profile.display_name'] = {
-            "$ne": "Slackbot"
-        }
-
-        if from_date or to_date:
-            pipeline['created_at'] = {}
-
-        if from_date:
-            start = from_date.astimezone(tz.tzutc())
-            pipeline['created_at']['$gte'] = start
-
-        if to_date:
-            end = to_date.astimezone(tz.tzutc())
-            pipeline['created_at']['$lte'] = end
-
-        if locations and len(locations) > 0:
-            pipeline['message.locations'] = {"$in": locations}
-
-        if country:
-            pipeline["message.slack_options.country"] = re.compile(country, re.IGNORECASE)
-
-        if user_id:
-            pipeline["$or"] = [
-                {"message.dedicated_slack_options": {"$exists": False}},
-                {"message.dedicated_slack_options": None},
-                {"message.dedicated_slack_options.user_id": f"{user_id}"},
-            ]
-        else:
-            pipeline["user_id"] = {'$exists': False}
-
-        if stop_words:
-            pipeline['full_message_text'] = {'$regex': f'^(?!.*({stop_words})).*$', '$options': 'i'}
-        elif text:
-            pipeline['$text'] = {'$search': text}
-
-        if publication_text:
-            pipeline['message.message'] = {'$regex': publication_text, '$options': 'i'}
-
-        if tags:
-            pipeline["tags"] = {"$elemMatch": {"$in": tags}}
-
-        if exclude_leads:
-            pipeline['id'] = {'$nin': exclude_leads}
-
-        if exclude_senders:
-            pipeline['message.sender_id'] = {'$nin': exclude_senders}
-
-        if excluded_channels:
-            pipeline['$and'] = []
-            for ws, channels in excluded_channels.items():
-                if channels is not None:
-                    pipeline['$and'].append(
-                        {'$or': [{'message.name': {'$ne': ws}}, {'message.channel_id': {'$nin': channels}}]})
-
-        if sender_ids:
-            pipeline['message.sender_id'] = {'$in': sender_ids}
-
-        if configs:
-            pipeline["message.configs.id"] = {"$not": {"$elemMatch": {"$nin": configs}}}
-
-        if bots_names is not None:
-            pipeline['message.name'] = {'$in': bots_names}
-
-        pipeline['message.profile.real_name'] = {'$ne': 'Slackbot'}
-
-        return pipeline
-
     def get_per_day(self, date: datetime):
         start_day = datetime(date.year, date.month, date.day, 0, 0, 0, tzinfo=tz.tzutc())
         end_day = datetime(date.year, date.month, date.day, 23, 59, 59, tzinfo=tz.tzutc())
@@ -615,51 +709,6 @@ class LeadMongoRepository(BaseMongoRepository):
         return [LeadModel.from_dic(x) for x in docs]
 
 
-class SpamLeadsMongoRepository(LeadMongoRepository):
-    pass
-
-    def __init__(self):
-        self.collection_name = 'spam_leads'
-
-    def get_list(self, skip, limit, sort_field: str = 'created_at', sort_direction: str = 'ASCENDING', **kwargs):
-        pipeline = self.__create_leads_filter(**kwargs)
-        sort_direction = pymongo.ASCENDING if sort_direction == 'ASCENDING' else pymongo.DESCENDING
-        docs = self.collection().find(pipeline).sort([(sort_field, sort_direction)]).skip(skip).limit(limit)
-        leads = [ExtendedLeadModel.from_dic(doc) for doc in docs]
-        senders = [lead.message.sender_id for lead in leads]
-        contacts = SlackContactUserRepository().find(users=senders)
-        for lead in leads:
-            lead.contact = next(filter(lambda x: x.sender_id == lead.message.sender_id, contacts), None)
-        return leads
-
-    def __create_leads_filter(self, **kwargs):
-        pipeline = {"user_id": {'$exists': False}}
-        text = kwargs.get('text', None)
-        stop_words = kwargs.get('stop_words', None)
-        if stop_words:
-            pipeline['full_message_text'] = {'$regex': f'^(?!.*({stop_words})).*$', '$options': 'i'}
-        elif text:
-            pipeline['$text'] = {'$search': text}
-
-        return pipeline
-
-
-class GarbageLeadsMongoRepository(SpamLeadsMongoRepository):
-    pass
-
-    def __init__(self):
-        super().__init__()
-        self.collection_name = 'garbage_leads'
-
-
-class GarbageUserLeadsMongoRepository(UserLeadMongoRepository):
-    pass
-
-    def __init__(self):
-        self.database_name = 'lgt_admin'
-        self.collection_name = 'garbage_leads'
-
-
 class SpamUserLeadsMongoRepository(UserLeadMongoRepository):
     pass
 
@@ -699,12 +748,12 @@ class BoardsMongoRepository(BaseMongoRepository):
         if not board:
             return None
 
-        board.statuses.append(BoardedStatus().from_dic({'name': 'Lead', 'order': 0}))
-        board.statuses.append(BoardedStatus().from_dic({'name': 'Prospect', 'order': 1}))
-        board.statuses.append(BoardedStatus().from_dic({'name': 'Opportunity', 'order': 2}))
-        board.statuses.append(BoardedStatus().from_dic({'name': 'Call', 'order': 3}))
-        board.statuses.append(BoardedStatus().from_dic({'name': 'Contract', 'order': 4}))
-        board.statuses.append(BoardedStatus().from_dic({'name': 'Refused', 'order': 5}))
+        board.statuses.append(BoardedStatus().from_dic({'id': 'Lead', 'name': 'Lead', 'order': 0}))
+        board.statuses.append(BoardedStatus().from_dic({'id': 'Prospect', 'name': 'Prospect', 'order': 1}))
+        board.statuses.append(BoardedStatus().from_dic({'id': 'Opportunity', 'name': 'Opportunity', 'order': 2}))
+        board.statuses.append(BoardedStatus().from_dic({'id': 'Call', 'name': 'Call', 'order': 3}))
+        board.statuses.append(BoardedStatus().from_dic({'id': 'Contract', 'name': 'Contract', 'order': 4}))
+        board.statuses.append(BoardedStatus().from_dic({'id': 'Refused', 'name': 'Refused', 'order': 5}))
 
         return self.update_board(user_id, board_id, statuses=board.statuses)
 
@@ -842,6 +891,9 @@ class DedicatedBotRepository(BaseMongoRepository):
         kwargs["only_valid"] = only_valid
         pipeline = self.__create_bots_filter(**kwargs)
         docs = self.collection().find(pipeline)
+        sort_by = kwargs.get('sort_by')
+        if sort_by:
+            docs = docs.sort({sort_by: 1})
         return [DedicatedBotModel.from_dic(doc) for doc in docs]
 
     def get_source_ids_for_user(self, **kwargs):
@@ -858,7 +910,7 @@ class DedicatedBotRepository(BaseMongoRepository):
 
     @staticmethod
     def __create_bots_filter(**kwargs):
-        pipeline = {}
+        pipeline: dict = {}
         name = kwargs.get('name')
         source_type = kwargs.get('source_type', None)
         user_name = kwargs.get('user_name')
@@ -870,6 +922,13 @@ class DedicatedBotRepository(BaseMongoRepository):
         source_id = kwargs.get('source_id')
         server_id = kwargs.get('server_id')
         active_server_id = kwargs.get('active_server_id')
+        invalid_creds = kwargs.get('invalid_creds')
+        sort_by = kwargs.get('sort_by')
+        deactivated_from = kwargs.get('deactivated_from')
+        user_ids = kwargs.get('user_ids')
+
+        if deactivated_from:
+            pipeline['deactivated_at'] = {'$gte': deactivated_from}
 
         if bot_id:
             pipeline["_id"] = to_object_id(bot_id)
@@ -898,12 +957,21 @@ class DedicatedBotRepository(BaseMongoRepository):
         if only_valid:
             pipeline['invalid_creds'] = False
 
+        if invalid_creds is not None:
+            pipeline['invalid_creds'] = invalid_creds
+
         if not include_deleted:
             pipeline['deleted'] = False
 
         if not include_paused and source_type == SourceType.DISCORD:
             pipeline['paused'] = False
 
+        if sort_by:
+            pipeline[sort_by] = {'$exists': True}
+
+        if user_ids is not None:
+            pipeline["user_id"] = {'$in': [to_object_id(_id) for _id in user_ids]}
+
         return pipeline
 
 
@@ -940,6 +1008,9 @@ class SlackContactUserRepository(BaseMongoRepository):
         pipeline = {"sender_id": user_id}
         return SlackMemberInformation.from_dic(self.collection().find_one(pipeline))
 
+    def update_source(self, source_id: str, source_data: dict):
+        self.collection().update_many({'source.source_id': source_id}, {'$set': {'source': source_data}})
+
 
 class UserTemplatesRepository(BaseMongoRepository):
     collection_name = "user_templates"
@@ -1010,6 +1081,11 @@ class UserContactsRepository(BaseMongoRepository):
         update_dict = {k: v for k, v in kwargs.items() if v is not None}
         self.collection().update_one(pipeline, {'$set': update_dict}, upsert=False)
 
+    def update_many(self, sender_id: str, **kwargs):
+        pipeline = {'sender_id': sender_id}
+        update_dict = {k: v for k, v in kwargs.items() if v is not None}
+        self.collection().update_many(pipeline, {'$set': update_dict}, upsert=False)
+
     def find_grouped_actual_contacts(self, user_id: ObjectId | str, **kwargs) -> dict[str, list[UserContact]]:
         spam = kwargs.get('spam')
         with_chat_only = kwargs.get('with_chat_only', False)
@@ -1135,15 +1211,70 @@ class ChatRepository(BaseMongoRepository):
 
         if from_date:
             start = datetime(from_date.year, from_date.month, from_date.day, tzinfo=tz.tzutc())
-            pipeline['last_action_at']['$gte'] = start
+            pipeline['created_at']['$gte'] = start
 
         if to_date:
             end = datetime(to_date.year, to_date.month, to_date.day, 23, 59, 59, tzinfo=tz.tzutc())
-            pipeline['last_action_at']['$lte'] = end
+            pipeline['created_at']['$lte'] = end
 
         return [ChatMessage.from_dic(msg)
                 for msg in self.collection().find(pipeline).sort("id", pymongo.ASCENDING)]
 
+    def get_aggregated_list(self, **kwargs):
+        match_pipeline = {}
+        user_id = kwargs.get('user_id')
+        from_date = kwargs.get('from_date')
+        to_date = kwargs.get('to_date')
+        sort_by = kwargs.get('sort_by', 'id')
+        viewed = kwargs.get('viewed')
+
+        if user_id:
+            match_pipeline['user_id'] = to_object_id(user_id)
+
+        if from_date or to_date:
+            match_pipeline['created_at'] = {}
+
+        if viewed is not None:
+            match_pipeline['viewed'] = viewed
+
+        if from_date:
+            start = datetime(from_date.year, from_date.month, from_date.day, tzinfo=tz.tzutc())
+            match_pipeline['created_at']['$gte'] = start
+
+        if to_date:
+            end = datetime(to_date.year, to_date.month, to_date.day, 23, 59, 59, tzinfo=tz.tzutc())
+            match_pipeline['created_at']['$lte'] = end
+
+        pipeline = [
+            {'$match': match_pipeline},
+            {
+                '$lookup': {
+                    'from': 'slack_contact',
+                    'localField': 'sender_id',
+                    'foreignField': 'sender_id',
+                    'as': 'user'
+                }
+            },
+            {
+                '$lookup': {
+                    'from': 'dedicated_bots',
+                    'localField': 'bot_id',
+                    'foreignField': '_id',
+                    'as': 'bot'
+                }
+            },
+            {
+                '$match':{'user': {'$ne': []}}
+            },
+            {
+                '$addFields': {'user': {'$first': '$user'}, 'bot': {'$first': '$bot'}}
+            },
+            {
+                '$sort': {sort_by: 1}
+            }]
+
+        return self.collection().aggregate(pipeline)
+
     def get_grouped_messages(self, **kwargs):
         match_pipeline = {}
         pipeline = [
@@ -1186,6 +1317,54 @@ class ChatRepository(BaseMongoRepository):
         self.collection().delete_one({"id": _id, 'user_id': to_object_id(user_id)})
 
 
+class MessageRequestsRepository(BaseMongoRepository):
+    collection_name = 'message_requests'
+
+    def upsert(self, user_id: str, sender_id: str, message_request: MessageRequest):
+        self.collection().update_one({'user_id': to_object_id(user_id), 'sender_id': sender_id},
+                                     {'$set': message_request.to_dic()}, upsert=True)
+
+    def get_many(self, user_id: str, viewed: bool = False, sort_direction: int = pymongo.ASCENDING, **kwargs):
+        match_pipeline = {'user_id': to_object_id(user_id), 'viewed': viewed}
+        from_date = kwargs.get('from_date')
+
+        if from_date:
+            start = datetime(from_date.year, from_date.month, from_date.day, tzinfo=tz.tzutc())
+            match_pipeline['created_at']['$gte'] = start
+
+        pipeline = [
+            {
+                '$match': match_pipeline
+            },
+            {
+                '$lookup': {
+                    'from': 'slack_contact',
+                    'localField': 'sender_id',
+                    'foreignField': 'sender_id',
+                    'as': 'user'
+                }
+            },
+            {
+                '$lookup': {
+                    'from': 'dedicated_bots',
+                    'localField': 'bot_id',
+                    'foreignField': '_id',
+                    'as': 'bot'
+                }
+            },
+            {
+                '$addFields': {'user': {'$first': '$user'}, 'bot': {'$first': '$bot'}}
+            },
+            {
+                '$sort': {'created_at': sort_direction}
+            }
+        ]
+        return self.collection().aggregate(pipeline)
+
+    def find(self, user_id: str, sender_id: str):
+        return self.collection().find_one({'user_id': to_object_id(user_id), 'sender_id': sender_id})
+
+
 class UserVerificationMongoRepository(BaseMongoRepository):
     pass
 
@@ -1216,8 +1395,11 @@ class SubscriptionsRepository(BaseMongoRepository):
         subscription_id = kwargs.get('id')
         trial = kwargs.get('trial')
         expired = kwargs.get('expired')
+        unverified = kwargs.get('unverified')
         if subscription_id:
             pipeline['_id'] = to_object_id(subscription_id)
+        if unverified is not None:
+            pipeline['unverified'] = unverified
         if trial is not None:
             pipeline['trial'] = trial
         if expired is not None:
