@@ -2,8 +2,8 @@ import json
 from datetime import datetime, UTC
 from lgt_jobs.lgt_common.pubsub.messages import publish_message2_pubsub
 from lgt_jobs.lgt_data.engine import DelayedJob
-from .basejobs import InvalidJobTypeException, BaseBackgroundJobData, BaseBackgroundJob
-from .env import background_jobs_topic
+from lgt_jobs.basejobs import InvalidJobTypeException, BaseBackgroundJobData, BaseBackgroundJob
+from lgt_jobs.env import background_jobs_topic
 
 
 def datetime_converter(o):
