@@ -1,7 +1,7 @@
 from abc import ABC
 from typing import Optional
 from pydantic import BaseModel
-from .basejobs import BaseBackgroundJobData, BaseBackgroundJob
+from lgt_jobs.basejobs import BaseBackgroundJobData, BaseBackgroundJob
 
 
 class SimpleTestJobData(BaseBackgroundJobData, BaseModel):
